<?php
/***************************************************************************
 *   Copyright (C) 2005-2020 by Ferenc Veres							   *
 *   lion@netngine.hu													   *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 3 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program.  If not, see <http://www.gnu.org/licenses/>. *
 ***************************************************************************/
include_once('/usr/share/php/adodb/adodb-exceptions.inc.php');
include_once('/usr/share/php/adodb/adodb.inc.php');

include_once('TranslationProject.php');
include_once('TranslationString.php');
include_once('TranslationWordList.php');
include_once('TranslationWord.php');
include_once('ProjectIterator.php');
include_once('StringIterator.php');

/**
 * Fix string for using in SQL statement
 *
 * @param $text The text to escape.
 * @returns The escaped text to use in SQL statements.
 */
 
function fixstr($text)
{
	return str_replace("'", "''", $text);
}

/**
 * Fix string for using in HTML input controls
 *
 * @param $text The text to escape.
 * @returns The escaped text &,<,>," replaced with HTML entities.
 */
 

function FixQuot($text)
{
	$s = str_replace("&", "&amp;", $text);
	$s = str_replace("\"", "&quot;", $s);
	$s = str_replace("<", "&lt;", $s);
	$s = str_replace(">", "&gt;", $s);
	return $s;
}
/**
 * Return a reference to the global database connection.
 */
 
function &GetDbConn()
{
	global $DB;
	return $DB;
}

/**
 * Return a reference to the short, interoperability table naming array.
 */

function &GetTables()
{
	$tables["WordIndex"] = "WordIndex";
	$tables["SentenceIndex"] = "SentenceIndex";
	$tables["Strings"] = "Strings";
	$tables["Projects"] = "Projects";
	$tables["Locales"] = "Locales";
	return $tables;
}

/**
* Return a variable value from the global $CONFIG array.
*/
function GetConfigVar($varName)
{
	global $CONFIG;
	return $CONFIG[$varName];
}

/**
* Load the word and sentence indexes and available locales into the related static class variables using the related static class methods.
*/

function CacheIndexes()
{
	TranslationString::InitSentenceLengthCache();
	//TranslationString::InitWordSentencesCache();
	TranslationWordList::InitWordsCache();
	TranslationProject::InitLocaleIDCache();
}

/**
 * Return current microtime timestamp for use in performance debug with ShowMicroTime()
 *
 * @return A float of current microseconds time.
 */
function GetMicroTime()
{
  list($usec, $sec) = explode(" ",microtime());
   return ((float)$usec + (float)$sec);
}

/**
 * Show time passed since basetime in microseconds unit.
 *
 * @param Float $basetime Time received from GetMicroTime earlier.
 * @param String $comment Comment to display before number.
 */
function ShowMicroTime($basetime, $comment = "")
{
	echo("<p>$comment".($comment != "" ? ": " : "").number_format(GetMicroTime()-$basetime, 6, ".", " ")."</p>");
}
?>
